use gdk::DisplayManager;

use crate::result::{MBGError, MBGResult};

pub fn get_max_resolution() -> MBGResult<(i32, i32)> {
    let manager = DisplayManager::get();
    let display = manager.get_default_display();
    if display.is_none() {
        return Err(MBGError::X11Error(String::from(
            "Default display not found.",
        )));
    }
    let display = display.unwrap();
    let n = display.get_n_monitors();
    debug!("Connected monitors: {}", n);
    let mut height = 0;
    let mut width = 0;
    for i in 0..n {
        let monitor = display.get_monitor(i);
        if let Some(monitor) = monitor {
            let work_area = monitor.get_workarea();
            if work_area.width >= width && work_area.height >= height {
                height = work_area.height;
                width = work_area.width;
            }
        }
    }
    debug!("Maximum found resolution is {}x{}", width, height);
    Ok((height, width))
}


// pub fn update_bg(img_bytes: Vec<u8>) -> MBGResult<()> {
//     debug!("TODO: Change background.");
//     file.write_all(img_bytes.as_slice())?;
//
//     // if let Err(setting_error) = out {
//     //     error!("Can't set background: {}", setting_error.to_string());
//     // }
//
//
//     // let screen = display.get_default_screen();
//     // let wins = screen.get_toplevel_windows();
//     // for win in wins.into_iter() {
//     //     let win_type = win.get_window_type();
//     //     debug!("{:?}", win_type);
//     // }
//     // let (conn, screen_num) = xcb::Connection::connect(None).unwrap();
//     // let setup = conn.get_setup();
//     // let screen = setup.roots().nth(screen_num as usize).unwrap();
//     // let count = setup.roots().count();
//     // debug!("{}", count);
//     // debug!("{}x{}", screen.width_in_pixels(), screen.height_in_pixels());
//     Ok(())
// }