use std::str::FromStr;

use fern::colors::{Color, ColoredLevelConfig};
use log::LevelFilter;

use crate::config::Config;

pub fn setup_logger() -> Result<(), fern::InitError> {
    let config = Config::get_props().logger;
    let level = config.level;
    let time_format = config.time_format;
    let colors = ColoredLevelConfig::new()
        .info(Color::Green)
        .warn(Color::Magenta)
        .debug(Color::Blue)
        .error(Color::Red)
        .trace(Color::BrightRed);
    fern::Dispatch::new()
        .format(move |out, message, record| {
            out.finish(format_args!(
                "{}[{}] {}",
                chrono::Local::now().format(time_format.as_str()),
                colors.color(record.level()),
                message
            ))
        })
        .level(LevelFilter::from_str(level.as_str()).unwrap())
        .chain(std::io::stdout())
        .apply()?;
    Ok(())
}
